@@ -1,14 +1,10 @@
-# -*- coding: utf-8 -*-
 """
 Simple example of GraphItem use.
 """
 
-
-import initExample ## Add path to library (just for examples; you do not need this)
+import numpy as np
 
 import pyqtgraph as pg
-from pyqtgraph.Qt import QtCore, QtGui
-import numpy as np
 
 # Enable antialiasing for prettier plots
 pg.setConfigOptions(antialias=True)
@@ -57,11 +53,5 @@ lines = np.array([
 ## Update the graph
 g.setData(pos=pos, adj=adj, pen=lines, size=1, symbol=symbols, pxMode=False)
 
-
-
-
-## Start Qt event loop unless running in interactive mode or using pyside.
 if __name__ == '__main__':
-    import sys
-    if (sys.flags.interactive != 1) or not hasattr(QtCore, 'PYQT_VERSION'):
-        QtGui.QApplication.instance().exec_()
+    pg.exec()
